@@ -95,11 +95,14 @@ class ModulesCommand(ToolkitCommand):
         print_warning: bool = True,
         skip_tracking: bool = False,
         silent: bool = False,
+        temp_dir_suffix: str | None = None,
         module_source_dir: Path | None = None,
     ):
         super().__init__(print_warning, skip_tracking, silent)
         self._module_source_dir: Path | None = module_source_dir
-        self._temp_download_dir = Path(tempfile.gettempdir()) / MODULES
+        # Use suffix to make temp directory unique (useful for parallel test execution)
+        modules_dir_name = f"{MODULES}.{temp_dir_suffix}" if temp_dir_suffix else MODULES
+        self._temp_download_dir = Path(tempfile.gettempdir()) / modules_dir_name
         if not self._temp_download_dir.exists():
             self._temp_download_dir.mkdir(parents=True, exist_ok=True)
 
@@ -170,6 +173,11 @@ class ModulesCommand(ToolkitCommand):
             print(f"{INDENT}[{'yellow' if mode == 'clean' else 'green'}]Creating {package_name}[/]")
 
             for module in package.modules:
+                if module.module_id:
+                    self._additional_tracking_info.installed_module_ids.add(module.module_id)
+                if module.package_id:
+                    self._additional_tracking_info.installed_package_ids.add(module.package_id)
+
                 if module.dir in seen_modules:
                     # A module can be part of multiple packages
                     continue
@@ -769,7 +777,6 @@ default_organization_dir = "{organization_dir.name}"''',
     def _get_available_packages(self, user_library: Library | None = None) -> tuple[Packages, Path]:
         """
         Returns a list of available packages, either from the CDF TOML file or from external libraries if the feature flag is enabled.
-        If the feature flag is not enabled and no libraries are specified, it returns the built-in modules.
         """
 
         cdf_toml = CDFToml.load()
@@ -778,9 +785,8 @@ default_organization_dir = "{organization_dir.name}"''',
 
             for library_name, library in libraries.items():
                 try:
-                    additional_tracking_info = self._additional_tracking_info.setdefault("downloadedLibraryIds", [])
-                    if library_name not in additional_tracking_info:
-                        additional_tracking_info.append(library_name)
+                    if library_name:
+                        self._additional_tracking_info.downloaded_library_ids.add(library_name)
 
                     print(f"[green]Adding library {library_name} from {library.url}[/]")
                     # Extract filename from URL, fallback to library_name.zip if no filename found
@@ -802,14 +808,12 @@ default_organization_dir = "{organization_dir.name}"''',
 
                     # Track deployment pack download for each package and module
                     for package in packages.values():
-                        downloaded_package_ids = self._additional_tracking_info.setdefault("downloadedPackageIds", [])
-                        if package.id and package.id not in downloaded_package_ids:
-                            downloaded_package_ids.append(package.id)
+                        if package.id:
+                            self._additional_tracking_info.downloaded_package_ids.add(package.id)
 
-                        downloaded_module_ids = self._additional_tracking_info.setdefault("downloadedModuleIds", [])
                         for module in package.modules:
-                            if module.module_id and module.module_id not in downloaded_module_ids:
-                                downloaded_module_ids.append(module.module_id)
+                            if module.module_id:
+                                self._additional_tracking_info.downloaded_module_ids.add(module.module_id)
 
                     return packages, file_path.parent
                 except Exception as e:
@@ -821,7 +825,7 @@ default_organization_dir = "{organization_dir.name}"''',
                         ) from e
 
                     raise ToolkitError(f"Failed to add library {library_name}, {e}")
-            # If no libraries are specified or the flag is not enabled, load the built-in modules
+            # If no libraries are specified or the flag is not enabled, raise an error
             raise ValueError("No valid libraries found.")
         else:
             if user_library:
