@@ -6,6 +6,13 @@ from ._asset_centric import AssetCentricFileSelector, AssetCentricSelector, Asse
 from ._base import DataSelector
 from ._canvas import CanvasSelector
 from ._charts import AllChartsSelector, ChartOwnerSelector, ChartSelector
+from ._datapoints import (
+    DataPointsFileSelector,
+    ExternalIdColumn,
+    InstanceColumn,
+    InternalIdColumn,
+    TimeSeriesColumn,
+)
 from ._instances import (
     InstanceFileSelector,
     InstanceSelector,
@@ -24,7 +31,8 @@ Selector = Annotated[
     | ChartOwnerSelector
     | AssetSubtreeSelector
     | AssetCentricFileSelector
-    | DataSetSelector,
+    | DataSetSelector
+    | DataPointsFileSelector,
     Field(discriminator="type"),
 ]
 
@@ -39,15 +47,20 @@ __all__ = [
     "CanvasSelector",
     "ChartOwnerSelector",
     "ChartSelector",
+    "DataPointsFileSelector",
     "DataSelector",
     "DataSetSelector",
+    "ExternalIdColumn",
+    "InstanceColumn",
     "InstanceFileSelector",
     "InstanceSelector",
     "InstanceSpaceSelector",
     "InstanceViewSelector",
+    "InternalIdColumn",
     "RawTableSelector",
     "SelectedTable",
     "SelectedView",
     "Selector",
     "SelectorAdapter",
+    "TimeSeriesColumn",
 ]
