@@ -14,6 +14,7 @@ from cognite_toolkit._cdf_tk.tk_warnings import HighSeverityWarning
 from cognite_toolkit._cdf_tk.utils.auxiliary import get_current_toolkit_version, get_user_agent
 from cognite_toolkit._cdf_tk.utils.http_client._data_classes import (
     BodyRequest,
+    DataBodyRequest,
     FailedRequestMessage,
     HTTPMessage,
     ItemsRequest,
@@ -147,13 +148,15 @@ class HTTPClient:
             timeout=self.config.timeout,
         )
 
-    def _create_headers(self, api_version: str | None = None) -> MutableMapping[str, str]:
+    def _create_headers(
+        self, api_version: str | None = None, content_type: str = "application/json", accept: str = "application/json"
+    ) -> MutableMapping[str, str]:
         headers: MutableMapping[str, str] = {}
         headers["User-Agent"] = f"httpx/{httpx.__version__} {get_user_agent()}"
         auth_name, auth_value = self.config.credentials.authorization_header()
         headers[auth_name] = auth_value
-        headers["content-type"] = "application/json"
-        headers["accept"] = "application/json"
+        headers["content-type"] = content_type
+        headers["accept"] = accept
         headers["x-cdp-sdk"] = f"CogniteToolkit:{get_current_toolkit_version()}"
         headers["x-cdp-app"] = self.config.client_name
         headers["cdf-version"] = api_version or self.config.api_subversion
@@ -162,7 +165,7 @@ class HTTPClient:
         return headers
 
     def _make_request(self, item: RequestMessage) -> httpx.Response:
-        headers = self._create_headers(item.api_version)
+        headers = self._create_headers(item.api_version, item.content_type, item.accept)
         params: dict[str, PrimitiveType] | None = None
         if isinstance(item, ParamRequest):
             params = item.parameters
@@ -171,6 +174,10 @@ class HTTPClient:
             data = item.data()
             if not global_config.disable_gzip:
                 data = gzip.compress(data.encode("utf-8"))
+        elif isinstance(item, DataBodyRequest):
+            data = item.data()
+            if not global_config.disable_gzip:
+                data = gzip.compress(data)
         return self.session.request(
             method=item.method,
             url=item.endpoint_url,
