@@ -92,6 +92,8 @@ class RequestMessage(HTTPMessage):
     read_attempt: int = 0
     status_attempt: int = 0
     api_version: str | None = None
+    content_type: str = "application/json"
+    accept: str = "application/json"
 
     @property
     def total_attempts(self) -> int:
@@ -171,6 +173,20 @@ class SimpleBodyRequest(SimpleRequest, BodyRequest):
         return _dump_body(self.body_content)
 
 
+@dataclass
+class DataBodyRequest(SimpleRequest):
+    data_content: bytes = b""
+
+    def data(self) -> bytes:
+        return self.data_content
+
+    def dump(self) -> dict[str, JsonVal]:
+        output = super().dump()
+        # We cannot serialize bytes, so we indicate its presence instead
+        output["data_content"] = "<bytes>"
+        return output
+
+
 T_COVARIANT_ID = TypeVar("T_COVARIANT_ID", covariant=True)
 
 
